package demo;

import java.util.Iterator;
import java.util.Set;

import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.activities.IActivity;
import org.eclipse.ui.activities.IActivityManager;
import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
import org.eclipse.ui.application.WorkbenchAdvisor;
import org.eclipse.ui.application.WorkbenchWindowAdvisor;

/**
 * This workbench advisor creates the window advisor, and specifies the
 * perspective id for the initial window.
 */
public class ApplicationWorkbenchAdvisor extends WorkbenchAdvisor {

  private static final String PERSPECTIVE_ID = "demo.perspective";

  public WorkbenchWindowAdvisor createWorkbenchWindowAdvisor( IWorkbenchWindowConfigurer configurer )
  {
    listActivities();
    return new ApplicationWorkbenchWindowAdvisor( configurer );
  }

  public String getInitialWindowPerspectiveId() {
    return PERSPECTIVE_ID;
  }

  // /////////////////
  // debug methods
  //
  private void listActivities() {
    StringBuilder buff = new StringBuilder();
    IActivityManager manager = PlatformUI.getWorkbench()
      .getActivitySupport()
      .getActivityManager();
    buff.append( " \n  Defined activities / IActivityManager.getDefinedActivityIds()\n" );
    doListActivities( buff, manager, manager.getDefinedActivityIds() );
    buff.append( " \n  Enabled activities / IActivityManager.getEnabledActivityIds()\n" );
    doListActivities( buff, manager, manager.getEnabledActivityIds() );
    System.out.println( buff.toString() );
  }

  private void doListActivities( final StringBuilder buff,
                                 final IActivityManager manager,
                                 final Set activities )
  {
    if( activities.size() == 0 ) {
      buff.append( "   (none)" );
    }
    for( Iterator iterator = activities.iterator(); iterator.hasNext(); ) {
      String activityId = ( String )iterator.next();
      IActivity activity = manager.getActivity( activityId );
      buff.append( "   " );
      // buff.append( activity.toString() );
      buff.append( activity.getId() );
      buff.append( " isEnabled => " );
      buff.append( activity.isEnabled() );
      buff.append( "\n" );
    }
  }
}
